package com.ruoyi.ss.bonus.mapper;

import com.ruoyi.common.domain.vo.CommonCountVO;
import com.ruoyi.common.domain.vo.CommonSumVO;
import com.ruoyi.common.domain.vo.LongDecimalVO;
import com.ruoyi.ss.bonus.domain.Bonus;
import com.ruoyi.ss.bonus.domain.BonusProvideQuery;
import com.ruoyi.ss.bonus.domain.BonusQuery;
import com.ruoyi.ss.bonus.domain.BonusVO;
import com.ruoyi.ss.bonus.domain.vo.BonusDailyAmountVO;
import com.ruoyi.ss.bonus.domain.vo.BonusMonthAmountVO;
import com.ruoyi.ss.bonus.domain.vo.ProvideBonusVO;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.List;

/**
 * 分成明细Mapper接口
 *
 * @author ruoyi
 * @date 2024-08-20
 */
public interface BonusMapper
{
    /**
     * 查询分成明细
     *
     * @param id 分成明细主键
     * @return 分成明细
     */
    public BonusVO selectBonusById(Long id);

    /**
     * 查询分成明细列表
     *
     * @param query 分成明细
     * @return 分成明细集合
     */
    public List<BonusVO> selectBonusList(@Param("query")BonusQuery query);

    /**
     * 新增分成明细
     *
     * @param bonus 分成明细
     * @return 结果
     */
    public int insertBonus(Bonus bonus);

    /**
     * 修改分成明细
     *
     * @param bonus 分成明细
     * @return 结果
     */
    public int updateBonus(@Param("data") Bonus bonus);

    /**
     * 删除分成明细
     *
     * @param id 分成明细主键
     * @return 结果
     */
    public int deleteBonusById(Long id);

    /**
     * 批量删除分成明细
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBonusByIds(Long[] ids);

    /**
     * 批量插入
     */
    int batchInsert(@Param("list") List<Bonus> bonusList);

    /**
     * 批量更新分成金额
     */
    int batchUpdateAmount(@Param("list") List<BonusVO> list);

    /**
     * 根据到账方统计
     */
    List<CommonCountVO<Long>> selectCountByArrival(@Param("query") BonusQuery query);

    /**
     * 根据到账方统计金额
     */
    List<CommonSumVO<Long>> selectBillAmountByArrival(@Param("query") BonusQuery query);

    /**
     * 查询提供分成
     */
    List<ProvideBonusVO> selectProvideBonus(@Param("query") BonusProvideQuery query);

    /**
     * 当未分成时退款
     */
    int refundWhenWaitDivide(@Param("id") Long id, @Param("amount") BigDecimal amount);

    /**
     * 当已分成时退款
     */
    int refundWhenDividend(@Param("id") Long id, @Param("amount") BigDecimal amount);

    /**
     * 按月查询
     */
    List<BonusMonthAmountVO> selectMonthAmount(@Param("query") BonusQuery query);

    /**
     * 按日查询
     */
    List<BonusDailyAmountVO> selectDailyAmount(@Param("query") BonusQuery query);

    /**
     * 支付分成
     * @param id 分成ID
     * @param amount 支付金额
     * @param payTime 支付时间
     */
    int pay(@Param("id") Long id, @Param("amount") BigDecimal amount, @Param("payTime") LocalDateTime payTime);

    /**
     * 查询数量
     * @param query
     * @return
     */
    int selectCount(@Param("query") BonusQuery query);

    /**
     * 查询未分成金额，并以到账方分组
     */
    List<LongDecimalVO> selectWaitAmountGroupByArrival(@Param("query") BonusQuery query);
}
